TryIntoHeaderValue

Trait TryIntoHeaderValue 

pub trait TryIntoHeaderValue: Sized {
    type Error: Into<Error>;

    // Required method
    fn try_into_value(self) -> Result<HeaderValue, Self::Error>;
}
An interface for types that can be converted into a HeaderValue.

Required Associated Types

type Error: Into<Error>

The type returned in the event of a conversion error.

Required Methods

fn try_into_value(self) -> Result<HeaderValue, Self::Error>

Try to convert value to a HeaderValue.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TryIntoHeaderValue for &[u8]

Source

impl TryIntoHeaderValue for &str

Source

impl TryIntoHeaderValue for Mime

Source

impl TryIntoHeaderValue for String

Source

impl TryIntoHeaderValue for Vec<u8>

Source

impl TryIntoHeaderValue for i32

Source

impl TryIntoHeaderValue for i64

Source

impl TryIntoHeaderValue for u32

Source

impl TryIntoHeaderValue for u64

Source

impl TryIntoHeaderValue for usize

Implementors

Source

impl TryIntoHeaderValue for &HeaderValue

Source

impl TryIntoHeaderValue for Accept

Source

impl TryIntoHeaderValue for AcceptCharset

Source

impl TryIntoHeaderValue for AcceptEncoding

Source

impl TryIntoHeaderValue for AcceptLanguage

Source

impl TryIntoHeaderValue for Allow

Source

impl TryIntoHeaderValue for Bytes

Source

impl TryIntoHeaderValue for CacheControl

Source

impl TryIntoHeaderValue for ContentDisposition

Source

impl TryIntoHeaderValue for ContentEncoding

Source

impl TryIntoHeaderValue for ContentLanguage

Source

impl TryIntoHeaderValue for ContentLength

Source

impl TryIntoHeaderValue for ContentRange

Source

impl TryIntoHeaderValue for ContentRangeSpec

Source

impl TryIntoHeaderValue for ContentType

Source

impl TryIntoHeaderValue for Date

Source

impl TryIntoHeaderValue for ETag

Source

impl TryIntoHeaderValue for EntityTag

Source

impl TryIntoHeaderValue for Expires

Source

impl TryIntoHeaderValue for HeaderValue

Source

impl TryIntoHeaderValue for HttpDate

Source

impl TryIntoHeaderValue for IfMatch

Source

impl TryIntoHeaderValue for IfModifiedSince

Source

impl TryIntoHeaderValue for IfNoneMatch

Source

impl TryIntoHeaderValue for IfRange

Source

impl TryIntoHeaderValue for IfUnmodifiedSince

Source

impl TryIntoHeaderValue for LastModified

Source

impl TryIntoHeaderValue for Range